@@ -47,11 +47,17 @@ const bool true = 1;
 /* Define if you want to enable workaround for KURLRequester problem */
 #undef KURLREQ_ERR
 
-/* Define if you want to enable workaround for popup menu problem */
-#undef KACTION_ERR
-
 /** base document type */
 #undef DOC
 
+/** document version */
+#undef DOCVERS
+
 /** enable kio retriever */
 #undef ENABLE_KIO
+
+/** check for kde with kapp revision >= 1.207 */
+#undef KDE_VERSION_POST_1207
+
+/** enable wget retriever */
+#undef ENABLE_WGET
