@@ -4,7 +4,7 @@
     begin                : Thu Dec 21 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.10 $
+    revision             : $Revision: 1.11 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -25,7 +25,7 @@
 #include "kmagodoc.h"
 #include "kcontainerview.h"
 
-const char KContainerView::MIMETYPE[MimeTypeNum][50] = 
+const char KContainerView::MIMETYPE[MimeTypeNum][50] =
 {
    "application/" DOC "-TManager-list",
    "application/" DOC "-Transfer-list",
@@ -33,8 +33,8 @@ const char KContainerView::MIMETYPE[MimeTypeNum][50] =
    "text/plain"
 };
 
-KContainerView::KContainerView(KMagoDoc *doc, Callback cb, KContainer c) 
-   : _doc(doc), _cnt(c), _callback(cb) 
+KContainerView::KContainerView(KMagoDoc *doc, Callback cb, KContainer c)
+   : _doc(doc), _cnt(c), _callback(cb)
 {
 }
 
@@ -42,28 +42,28 @@ KContainerView::~KContainerView()
 {
 }
 
-KMagoDoc * KContainerView::doc() const 
+KMagoDoc * KContainerView::doc() const
 {
    return _doc;
 }
 
-KMagoView * KContainerView::view() const 
-{ 
+KMagoView * KContainerView::view() const
+{
    return doc()->view();
 }
 
-KContainer KContainerView::container() const 
+KContainer KContainerView::container() const
 {
    return _cnt;
 }
 
-void KContainerView::setContainer(KContainer c) 
+void KContainerView::setContainer(KContainer c)
 {
    _cnt = c;
    reset();
 }
 
-void KContainerView::reset() 
+void KContainerView::reset()
 {
    kdDebug(D_VIE) << name() << ": reset view" << endl;
    clear();
@@ -73,8 +73,8 @@ void KContainerView::reset()
       itemAdd(it.current());
 }
 
-bool KContainerView::dropItemList(KContainer source, KContainer target, 
-				  bool move, QDomDocument dom) 
+bool KContainerView::dropItemList(KContainer source, KContainer target,
+				  bool move, QDomDocument dom)
 {
    // drop a list of items
    kdDebug(D_RUN) << "dropItemList : DOC #" << dom.toString() << "#" << endl;
@@ -84,7 +84,7 @@ bool KContainerView::dropItemList(KContainer source, KContainer target,
       kdDebug(D_RUN) << "dropItemList : version not correct" << endl;
       return false;
    }
-   if ((target.itemType() & e.attribute("Type").toInt()) != target.itemType()) 
+   if ((target.itemType() & e.attribute("Type").toInt()) != target.itemType())
    {
       kdDebug(D_RUN) << "dropItemList : item type not handled by container" << endl;
       return false;
@@ -94,28 +94,28 @@ bool KContainerView::dropItemList(KContainer source, KContainer target,
       kdDebug(D_RUN) << "dropItemList : source " << source.name() << endl;
    else
       kdDebug(D_RUN) << "dropItemList : source unknown" << endl;
-   if (move) 
+   if (move)
    {
       //event->acceptAction(true);
       kdDebug(D_RUN) << "dropItemList : move" << endl;
-   } 
-   else 
+   }
+   else
    {
       //event->accept(true);
       kdDebug(D_RUN) << "dropItemList : copy" << endl;
    }
    kdDebug(D_RUN) << "dropItemList : target " << target.name() << endl;
    QDomNode n = e.firstChild();
-   while (!n.isNull()) 
+   while (!n.isNull())
    {
       e = n.toElement();
       kdDebug(D_RUN) << "dropItemList : drop item " << e.attribute("Name") << endl;
       KObject item = target.itemCopy(e);
       kdWarning(item.isNull(), D_RUN) << "dropItemList : error creating item" << endl;
-      if (!item.isNull()) 
+      if (!item.isNull())
       {
 	 kdDebug(D_RUN) << "dropItemList : create " << item.name() << endl;
-	 if (move) 
+	 if (move)
 	 {
 	    kdDebug(D_RUN) << "dropItemList : remove " << e.attribute("Id") << endl;
 	    //source.itemRemove(source.itemFindId(e.attribute("Id").toInt()));
@@ -132,8 +132,8 @@ bool KContainerView::dropItemList(KContainer source, KContainer target,
    return true;
 }
 
-bool KContainerView::dropUriList(KMagoDoc *doc, KContainer target, 
-				 QStrList &uris) 
+bool KContainerView::dropUriList(KMagoDoc *doc, KContainer target,
+				 QStrList &uris)
 {
    kdDebug(D_RUN) << "dropUriList: " << endl;
    for (char *uri = uris.first(); uri != 0; uri = uris.next())
@@ -141,14 +141,14 @@ bool KContainerView::dropUriList(KMagoDoc *doc, KContainer target,
    return true;
 }
 
-bool KContainerView::dropText(KMagoDoc *doc, KContainer target, 
-			      const QString &text) 
+bool KContainerView::dropText(KMagoDoc *doc, KContainer target,
+			      const QString &text)
 {
    kdDebug(D_RUN) << "dropText : TEXT=" << text << endl;
    QString buf = text;
    QTextIStream s(&buf);
    QString line;
-   while (!s.atEnd()) 
+   while (!s.atEnd())
    {
       s >> line;
       doc->addTransfer(line, target.toTManager());
@@ -156,7 +156,7 @@ bool KContainerView::dropText(KMagoDoc *doc, KContainer target,
    return true;
 }
 
-bool KContainerView::acceptDrop(const QDropEvent *event, KContainer target) 
+bool KContainerView::acceptDrop(const QDropEvent *event, KContainer target)
 {
    KContainer source;
    if (dynamic_cast<KContainerView*>(event->source()) != 0)
@@ -164,7 +164,7 @@ bool KContainerView::acceptDrop(const QDropEvent *event, KContainer target)
    else
       return true;
    //FIXME!! aggiungi se target.isChildOf(source)
-   if (source == target) 
+   if (source == target)
    {
       //kdWarning(D_RUN) << target.name() << ": drop on source" << endl;
       return false;
@@ -179,17 +179,17 @@ bool KContainerView::acceptDrop(const QDropEvent *event, KContainer target)
 }
 
 void KContainerView::dropTransferList(QDropEvent *event, KMagoDoc *doc,
-				      KContainer target) 
+				      KContainer target)
 {
-   if (!acceptDrop(event, target)) 
+   if (!acceptDrop(event, target))
    {
       event->ignore();
       return;
    }
-   if (event->provides(MIMETYPE[MimeTransferList])) 
+   if (event->provides(MIMETYPE[MimeTransferList]))
    {
       QDomDocument dom("item-list");
-      if (!dom.setContent(event->encodedData(MIMETYPE[MimeTransferList]))) 
+      if (!dom.setContent(event->encodedData(MIMETYPE[MimeTransferList])))
       {
 	 kdWarning(D_RUN) << "dropTransferList : error decoding transfer-list " << dom.toString() << endl;
 	 event->ignore();
@@ -199,26 +199,36 @@ void KContainerView::dropTransferList(QDropEvent *event, KMagoDoc *doc,
       if (dynamic_cast<KContainerView*>(event->source()) != 0)
 	 source = dynamic_cast<KContainerView*>(event->source())->container();
       event->acceptAction(dropItemList(source, target, event->action() == QDropEvent::Move && !source.isNull(), dom));
-   } 
-   else if (event->provides(MIMETYPE[MimeUriList])) 
+   }
+   else if (event->provides(MIMETYPE[MimeUriList]))
    {
       QStrList lst;
-      QUriDrag::decode(event, lst);
-      event->accept(dropUriList(doc, target, lst));
-   } 
-   else if (event->provides(MIMETYPE[MimeText])) 
+      if (QUriDrag::decode(event, lst))
+	 event->accept(dropUriList(doc, target, lst));
+      else
+	 event->ignore();
+   }
+   else if (event->provides(MIMETYPE[MimeText]))
    {
       QString text;
-      QTextDrag::decode(event, text);
+      //FIXME error in QTextDrag::decode
+      //kdDebug() << "TEXT DATA=" << QString(event->encodedData("text/plain")) << endl;
+      text = QString(event->encodedData(MIMETYPE[MimeText]));
       event->accept(dropText(doc, target, text));
-   } 
+      /*
+      if (QTextDrag::decode(event, text))
+	 event->accept(dropText(doc, target, text));
+      else
+         event->ignore();
+      */
+   }
    else
       event->ignore();
 }
 
-void KContainerView::dropTManagerList(QDropEvent *event, KContainer target) 
+void KContainerView::dropTManagerList(QDropEvent *event, KContainer target)
 {
-   if (!acceptDrop(event, target)) 
+   if (!acceptDrop(event, target))
    {
       event->ignore();
       return;
@@ -230,10 +240,10 @@ void KContainerView::dropTManagerList(QDropEvent *event, KContainer target)
     kdDebug(D_RUN) << name() << ": drop item " << id << endl;
   }
   */
-   if (event->provides(MIMETYPE[MimeTManagerList])) 
+   if (event->provides(MIMETYPE[MimeTManagerList]))
    {
       QDomDocument dom("item-list");
-      if (!dom.setContent(event->encodedData(MIMETYPE[MimeTManagerList]))) 
+      if (!dom.setContent(event->encodedData(MIMETYPE[MimeTManagerList])))
       {
 	 kdWarning(D_RUN) << "dropTManagerList : error decoding tmanager-list" << dom.toString() << endl;
 	 event->ignore();
@@ -243,72 +253,89 @@ void KContainerView::dropTManagerList(QDropEvent *event, KContainer target)
       if (dynamic_cast<KContainerView*>(event->source()) != 0)
 	 source = dynamic_cast<KContainerView*>(event->source())->container();
       event->acceptAction(dropItemList(source, target, event->action() == QDropEvent::Move && !source.isNull(), dom));
-   } 
+   }
    else
       event->ignore();
 }
 
-bool KContainerView::transferCanDecode(const QMimeSource *e) 
+bool KContainerView::transferCanDecode(const QMimeSource *e)
 {
-   return (e->provides(MIMETYPE[MimeTransferList])
-	   || e->provides(MIMETYPE[MimeUriList]));
+   bool retval = (e->provides(MIMETYPE[MimeTransferList])
+		  || e->provides(MIMETYPE[MimeUriList])
+		  || e->provides(MIMETYPE[MimeText])
+      );
+   if (!retval)
+   {
+      const char *fmt;
+      QString ln;
+      for (int i = 0; ; ++i)
+      {
+	 fmt = e->format(i);
+	 if (fmt == 0)
+	    break;
+	 ln += QString(" : ") + fmt;
+      }
+      kdDebug(D_RUN) << ": transferCanDecode " << ln << endl;
+   }
+   return retval;
 }
 
-bool KContainerView::managerCanDecode(const QMimeSource *e) 
+bool KContainerView::managerCanDecode(const QMimeSource *e)
 {
    return (e->provides(MIMETYPE[MimeTManagerList])
 	   || e->provides(MIMETYPE[MimeTransferList])
-	   || e->provides(MIMETYPE[MimeUriList]));
+	   || e->provides(MIMETYPE[MimeUriList])
+      );
 }
 
-QByteArray KContainerView::managerEncodedData(const KTManager::List &mngrs, 
-					      const char* mimetype) 
+QByteArray KContainerView::managerEncodedData(const KTManager::List &mngrs,
+					      const char* mimetype)
 {
    QByteArray data;
    QTextStream s(data, IO_WriteOnly);
-   if (strcmp(mimetype, MIMETYPE[MimeTManagerList]) == 0) 
+   if (strcmp(mimetype, MIMETYPE[MimeTManagerList]) == 0)
    {
       s << "<?xml version = '1.0'?><!DOCTYPE item-list >"
-	<< "<item-list Version=\"" << DOCVERS 
+	<< "<item-list Version=\"" << DOCVERS
 	<< "\" Type=\"" << TYP_TMANAGER_T << "\">" << endl;
-      for (KTManager::List::ConstIterator i = mngrs.begin(); 
+      for (KTManager::List::ConstIterator i = mngrs.begin();
 	   i != mngrs.end(); ++i)
 	 (*i).dom().save(s, 1);
       s << "</item-list>" << endl;
-   } 
-   else if (strcmp(mimetype, MIMETYPE[MimeTransferList]) == 0) 
+   }
+   else if (strcmp(mimetype, MIMETYPE[MimeTransferList]) == 0)
    {
       s << "<?xml version = '1.0'?><!DOCTYPE item-list >"
 	<< "<item-list Version=\"" << DOCVERS
 	<< "\" Type=\"" << TYP_FILE_TRANSFER_T << "\">" << endl;
-      for (KTManager::List::ConstIterator i = mngrs.begin(); 
+      for (KTManager::List::ConstIterator i = mngrs.begin();
 	   i != mngrs.end(); ++i)
 	 for (KCntIterator it(*i); !it.current().isNull(); ++it)
 	    it.current().dom().save(s, 1);
       s << "</item-list>" << endl;
-   } 
-   else if (strcmp(mimetype, MIMETYPE[MimeUriList]) == 0) 
+   }
+   else if (strcmp(mimetype, MIMETYPE[MimeUriList]) == 0)
    {
       QStrList lst;
-      for (KTManager::List::ConstIterator i = mngrs.begin(); 
+      for (KTManager::List::ConstIterator i = mngrs.begin();
 	   i != mngrs.end(); ++i)
 	 for (KCntIterator it(*i); !it.current().isNull(); ++it)
 	    lst.append(QUriDrag::unicodeUriToUri(it.current().toTransfer().remote().url())); //FIXME??
       data = QUriDrag(lst, 0).encodedData("text/uri-list");
-   } 
-   else 
+   }
+   else
    {
       kdFatal(D_RUN) << "managerEncodedData : UNKNOWN MIME" << endl;
    }
    return data;
 }
 
-QByteArray KContainerView::transferEncodedData(const KTransfer::List &trns, 
-					       const char* mimetype) 
+QByteArray KContainerView::transferEncodedData(const KTransfer::List &trns,
+					       const char* mimetype)
 {
    QByteArray data;
    QTextStream s(data, IO_WriteOnly);
-   if (strcmp(mimetype, MIMETYPE[MimeTransferList]) == 0) 
+   if (strcmp(mimetype, MIMETYPE[MimeTransferList]) == 0)
    {
       s << "<?xml version = '1.0'?><!DOCTYPE item-list >"
 	<< "<item-list Version=\"" << DOCVERS
@@ -316,23 +343,23 @@ QByteArray KContainerView::transferEncodedData(const KTransfer::List &trns,
       for (KTransfer::List::ConstIterator i = trns.begin(); i != trns.end(); ++i)
 	 (*i).dom().save(s, 1);
       s << "</item-list>" << endl;
-   } 
-   else if (strcmp(mimetype, MIMETYPE[MimeUriList]) == 0) 
+   }
+   else if (strcmp(mimetype, MIMETYPE[MimeUriList]) == 0)
    {
       for (KTransfer::List::ConstIterator i = trns.begin(); i != trns.end(); ++i)
 	 s << (*i).remote().url() << endl;
-   } 
-   else 
+   }
+   else
    {
       kdFatal(D_RUN) << "transferEncodedData : UNKNOWN MIME" << endl;
    }
    return data;
 }
 
-const char* KContainerView::managerFormat(int i) 
+const char* KContainerView::managerFormat(int i)
 {
    //kdDebug(D_RUN) << "managerFormat : drag format " << i << endl;
-   switch (i) 
+   switch (i)
    {
    case 0: return MIMETYPE[MimeTManagerList];
    case 1: return MIMETYPE[MimeTransferList];
@@ -341,10 +368,10 @@ const char* KContainerView::managerFormat(int i)
    return 0;
 }
 
-const char* KContainerView::transferFormat(int i) 
+const char* KContainerView::transferFormat(int i)
 {
    //kdDebug(D_RUN) << "transferFormat : drag format " << i << endl;
-   switch (i) 
+   switch (i)
    {
    case 0: return MIMETYPE[MimeTransferList];
    case 1: return MIMETYPE[MimeUriList];
@@ -352,18 +379,18 @@ const char* KContainerView::transferFormat(int i)
    return 0;
 }
 
-bool KContainerView::transferDragEnabled(KTransfer t) 
+bool KContainerView::transferDragEnabled(KTransfer t)
 {
    return (!t.isNull() && !t.isRunning());
 }
 
-bool KContainerView::managerDragEnabled(KTManager m) 
+bool KContainerView::managerDragEnabled(KTManager m)
 {
-   return (!m.isNull() && m.itemActiveCount() == 0 
+   return (!m.isNull() && m.itemActiveCount() == 0
 	   && m.container().itemCount() > 1);
 }
 
-KTManager KContainerView::selectManager(KMagoDoc *doc) 
+KTManager KContainerView::selectManager(KMagoDoc *doc)
 {
    KPopupMenu *mngrList = new KPopupMenu(kapp->mainWidget());
    //mngrList->insertTitle(i18n("Select Manager"));
@@ -393,9 +420,9 @@ bool KContainerView::managerToClipboard(KTManager m, bool cut)
 
 bool KContainerView::transferToClipboard(KTransfer t, bool cut)
 {
-   if (!transferDragEnabled(t)) 
+   if (!transferDragEnabled(t))
       return false;
-   kapp->clipboard()->setData(new QTextDrag(t.remote().url(), 
+   kapp->clipboard()->setData(new QTextDrag(t.remote().url(),
 					    kapp->mainWidget()));
    if (cut)
       t.container().itemRemove(t);
@@ -405,10 +432,10 @@ bool KContainerView::transferToClipboard(KTransfer t, bool cut)
 bool KContainerView::managersPasteFromClipboard(KMManager m)
 {
    QMimeSource *mime = kapp->clipboard()->data();
-   if (!mime->provides(MIMETYPE[MimeTManagerList])) 
+   if (!mime->provides(MIMETYPE[MimeTManagerList]))
       return false;
    QDomDocument dom("item-list");
-   if (!dom.setContent(mime->encodedData(MIMETYPE[MimeTManagerList]))) 
+   if (!dom.setContent(mime->encodedData(MIMETYPE[MimeTManagerList])))
    {
       kdWarning(D_RUN) << ": managersPasteFromClipboard: error decoding item-list" << dom.toString() << endl;
       return false;
@@ -419,10 +446,10 @@ bool KContainerView::managersPasteFromClipboard(KMManager m)
 bool KContainerView::transfersPasteFromClipboard(KTManager m)
 {
    QMimeSource *mime = kapp->clipboard()->data();
-   if (!mime->provides(MIMETYPE[MimeTransferList])) 
+   if (!mime->provides(MIMETYPE[MimeTransferList]))
       return false;
    QDomDocument dom("item-list");
-   if (!dom.setContent(mime->encodedData(MIMETYPE[MimeTransferList]))) 
+   if (!dom.setContent(mime->encodedData(MIMETYPE[MimeTransferList])))
    {
       kdWarning(D_RUN) << ": transfersPasteFromClipboard : error decoding item-list " << dom.toString() << endl;
       return false;
@@ -447,10 +474,10 @@ bool KContainerView::urisPasteFromClipboard(KMagoDoc *doc)
 bool KContainerView::textsPasteFromClipboard(KMagoDoc *doc)
 {
    QMimeSource *mime = kapp->clipboard()->data();
-   if (!mime->provides(MIMETYPE[MimeText])) 
+   if (!mime->provides(MIMETYPE[MimeText]))
       return false;
    QString text;
-   if (!QTextDrag::decode(kapp->clipboard()->data(), text)) 
+   if (!QTextDrag::decode(kapp->clipboard()->data(), text))
    {
       kdWarning(D_RUN) << ": textsPasteFromClipboard : paste text: decode fail" << endl;
       return false;
@@ -461,26 +488,26 @@ bool KContainerView::textsPasteFromClipboard(KMagoDoc *doc)
 ////////////////////////////////////////////////////////////////////
 
 KTransferListDrag::KTransferListDrag(QWidget *dragSource, const char *name)
-   : QDragObject(dragSource, name) 
+   : QDragObject(dragSource, name)
 {
 }
 
-const char* KTransferListDrag::format(int i) const 
+const char* KTransferListDrag::format(int i) const
 {
    return KContainerView::transferFormat(i);
 }
 
-QByteArray KTransferListDrag::encodedData(const char* mimetype) const 
+QByteArray KTransferListDrag::encodedData(const char* mimetype) const
 {
    return KContainerView::transferEncodedData(trns, mimetype);
 }
 
-bool KTransferListDrag::canDecode(const QMimeSource *e) 
+bool KTransferListDrag::canDecode(const QMimeSource *e)
 {
    return KContainerView::transferCanDecode(e);
 }
 
-void KTransferListDrag::append(KTransfer t) 
+void KTransferListDrag::append(KTransfer t)
 {
    trns << t;
 }
@@ -488,26 +515,26 @@ void KTransferListDrag::append(KTransfer t)
 ////////////////////////////////////////////////////////////////////
 
 KTManagerListDrag::KTManagerListDrag(QWidget *dragSource, const char *name)
-   : QDragObject(dragSource, name) 
+   : QDragObject(dragSource, name)
 {
 }
 
-const char* KTManagerListDrag::format(int i) const 
+const char* KTManagerListDrag::format(int i) const
 {
    return KContainerView::managerFormat(i);
 }
 
-QByteArray KTManagerListDrag::encodedData(const char* mimetype) const 
+QByteArray KTManagerListDrag::encodedData(const char* mimetype) const
 {
    return KContainerView::managerEncodedData(mngrs, mimetype);
 }
 
-bool KTManagerListDrag::canDecode(const QMimeSource *e) 
+bool KTManagerListDrag::canDecode(const QMimeSource *e)
 {
    return KContainerView::managerCanDecode(e);
 }
 
-void KTManagerListDrag::append(KTManager m) 
+void KTManagerListDrag::append(KTManager m)
 {
    mngrs << m;
 }
