@@ -4,7 +4,7 @@
     begin                : Fri Sep 15 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.15 $
+    revision             : $Revision: 1.18 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,6 +21,7 @@
 #include <config.h>
 #endif
 
+#include <ktabctl.h>
 #include <qwidget.h>
 #include <qgroupbox.h>
 #include <qcheckbox.h>
@@ -29,7 +30,6 @@
 #include <qlineedit.h>
 #include <qbuttongroup.h>
 #include <qradiobutton.h>
-#include <klocale.h>
 
 #ifdef DMALLOC
 #include <dmalloc.h>
@@ -39,13 +39,13 @@ class KMagoDoc;
 
 /**
  * @short Dialog class for @ref KMagoApp configuration
- * 
+ *
  * @author Sergio Moretti
- * 
- * @version $Id: kdlgapp.h,v 1.15 2001/03/23 17:14:59 sergio Exp $
+ *
+ * @version $Id: kdlgapp.h,v 1.18 2001/04/04 18:06:04 sergio Exp $
  */
 
-class KDlgApp : public QWidget 
+class KDlgApp : public KTabCtl
 {
    Q_OBJECT
 public:
@@ -59,9 +59,16 @@ protected:
    /** get the start mode */
    int getStartMode();
    KMagoDoc * doc() const;
-	
+
+public slots:
+   void accept();
+   void reject();
+
 protected:
-   QCheckBox *cbtExitOnIdle;
+   QLineEdit *lneCmdOnIdle;
+   QCheckBox *cbtTrayProgress;
+   QCheckBox *cbtAutoProgress;
+   QCheckBox *cbtNotify;
    QCheckBox *cbtLoadLast;
    QCheckBox *cbtAEFile;
    QCheckBox *cbtNoPrompt;
@@ -75,10 +82,6 @@ protected:
    QRadioButton *rbtStart2;
    QCheckBox *cbtListOnDrop;
 
-public slots:
-   void accept();
-   void reject();
-  
 private:
    KMagoDoc * _doc;
 };
