@@ -4,10 +4,8 @@
     begin                : Wed Sep 6 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.16 $
- ***************************************************************************/
-
-/***************************************************************************
+    revision             : $Revision: 1.17 $
+ ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,10 +13,12 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+
 #include <kapp.h>
 #include <kfiledialog.h>
 #include <qtooltip.h>
 #include <qlayout.h>
+#include <klocale.h>
 #include <qhbox.h>
 #include "ktmanager.h"
 #include "kdlgmanager1.h"
@@ -169,10 +169,14 @@ void  KDlgManager1::initDialog()
    box->setStretchFactor(lneMinBand, 0);
 
    //FIXME!! 3 column instead of 2???
+#ifndef KURLREQ_ERR
 #ifdef KDE_VERSION_POST_1207
    gbox = new QGroupBox(2, Horizontal, i18n("Directory & Files"), this, "Grb4");
 #else
    gbox = new QGroupBox(3, Horizontal, i18n("Directory & Files"), this, "Grb4");
+#endif
+#else
+   gbox = new QGroupBox(2, Horizontal, i18n("Directory & Files"), this, "Grb4");
 #endif
    l->addWidget(gbox);
 
@@ -191,9 +195,7 @@ void  KDlgManager1::initDialog()
    QToolTip::add(cmbDDir,i18n("Path of directory storing downloaded files"));
 #else
    lneDDir = new QLineEdit(gbox, "LneDDir");
-   btnDDir = new QPushButton(SmallIcon("fileopen"), QString::null, gbox, "BtnDDir");
    QToolTip::add(lneDDir,i18n("Path of directory storing downloaded files"));
-   connect(btnDDir, SIGNAL(clicked()), this, SLOT(slotOpenDDir()));
 #endif
 
    lbl = new QLabel(i18n("Working Dir"), gbox, "lblWDir");
@@ -211,10 +213,7 @@ void  KDlgManager1::initDialog()
    QToolTip::add(cmbWDir, i18n("Path of directory storing temporary files"));
 #else
    lneWDir = new QLineEdit(gbox, "LneWDir");
-   btnWDir = new QPushButton(SmallIcon("fileopen"), QString::null, gbox, 
-			     "BtnWDir");
    QToolTip::add(lneWDir,i18n("Path of directory storing temporary files"));
-   connect(btnWDir, SIGNAL(clicked()), this, SLOT(slotOpenWDir()));
 #endif
 
    lbl = new QLabel(i18n("Log File"), gbox, "lblLog");
@@ -232,9 +231,7 @@ void  KDlgManager1::initDialog()
    QToolTip::add(cmbLog, i18n("Path of log file"));
 #else
    lneLog = new QLineEdit(gbox, "LneLog");
-   btnLog = new QPushButton(SmallIcon("fileopen"), QString::null, gbox, "BtnLog");
    QToolTip::add(lneLog,i18n("Path of log file"));
-   connect(btnLog, SIGNAL(clicked()), this, SLOT(slotOpenLogFile()));
 #endif  
 
    adjustSize();
@@ -271,8 +268,8 @@ bool KDlgManager1::isAcceptable()
    return true;
 }
 
-/** update the dialog after a change in global checkbutton */
-void KDlgManager1::slotSetGlobal(bool on){
+void KDlgManager1::slotSetGlobal(bool on)
+{
    mngr.setGlobal(on);
    cbtAutoDownload->setEnabled(!on);
    cbtRemoveCompleted->setEnabled(!on);
@@ -286,11 +283,8 @@ void KDlgManager1::slotSetGlobal(bool on){
    cmbLog->setEnabled(!on);
 #else
    lneDDir->setEnabled(!on);
-   btnDDir->setEnabled(!on);
    lneWDir->setEnabled(!on);
-   btnWDir->setEnabled(!on);
    lneLog->setEnabled(!on);
-   btnLog->setEnabled(!on);
 #endif
    cmbType->setEnabled(!on);
    init();
@@ -298,33 +292,7 @@ void KDlgManager1::slotSetGlobal(bool on){
    emit sigGlobalChange(on);
 }
 
-#ifdef KURLREQ_ERR
-void KDlgManager1::slotOpenDDir() {
-   QString dir = lneDDir->text();
-   dir = KFileDialog::getExistingDirectory(dir, this, 
-					   i18n("Select Download Directory"));
-   if (!dir.isEmpty())
-      lneDDir->setText(dir);
-}
-
-void KDlgManager1::slotOpenWDir() {
-   QString dir = lneWDir->text();
-   dir = KFileDialog::getExistingDirectory(dir, this, 
-					   i18n("Select Working Directory"));
-   if (!dir.isEmpty())
-      lneWDir->setText(dir);
-}
-
-void KDlgManager1::slotOpenLogFile() {
-   QString file = lneLog->text();
-   file = KFileDialog::getSaveFileName(QDir::currentDirPath(), 
-				       QString::null,
-				       this, 
-				       i18n("Select Log File"));
-   if (!file.isEmpty())
-      lneLog->setText(file);
-}
-#else
+#ifndef KURLREQ_ERR
 #ifdef KDE_VERSION_POST_1207
 void KDlgManager1::slotOpenFileDialog(KURLRequester *kreq)
 {
