@@ -4,7 +4,7 @@
     begin                : Wed Sep 6 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.14 $
+    revision             : $Revision: 1.15 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -29,7 +29,6 @@
 #include <qpushbutton.h>
 #include <kurlrequester.h>
 #include <kcombobox.h>
-#include <klocale.h>
 #include <qvaluelist.h>
 #include "ktmanager.h"
 
@@ -42,7 +41,7 @@
  * 
  * @author Sergio Moretti
  *
- * @version $Id: kdlgmanager1.h,v 1.14 2001/03/05 20:59:22 sergio Exp $
+ * @version $Id: kdlgmanager1.h,v 1.15 2001/03/29 08:38:48 sergio Exp $
  */
 
 class KDlgManager1 : public QWidget  
@@ -74,11 +73,8 @@ protected:
    KURLRequester *cmbLog;
 #else
    QLineEdit *lneDDir;
-   QPushButton *btnDDir;
    QLineEdit *lneWDir;
-   QPushButton *btnWDir;
    QLineEdit *lneLog;
-   QPushButton *btnLog;
 #endif
 
 public slots:
@@ -90,18 +86,13 @@ protected slots:
    /** update the dialog after a change in global checkbutton */
    void slotSetGlobal(bool on);
 #ifndef KURLREQ_ERR
-   void slotOpenDDir() {}
-   void slotOpenWDir() {}
-   void slotOpenLogFile() {}
 #ifdef KDE_VERSION_POST_1207
    void slotOpenFileDialog(KURLRequester *kreq);
 #else
    void slotOpenFileDialog(KURLRequester *) {}
 #endif
 #else
-   void slotOpenDDir();
-   void slotOpenWDir();
-   void slotOpenLogFile();
+   void slotOpenFileDialog(KURLRequester *) {}
 #endif
 
 signals:
