@@ -4,7 +4,7 @@
     begin                : Fri Sep 15 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.19 $
+    revision             : $Revision: 1.20 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -32,23 +32,23 @@
 KDlgOpenTransfer * KDlgOpenTransfer::dlg = 0;
 
 
-KDlgOpenTransfer::KDlgOpenTransfer(QWidget *parent, const char *name) : 
+KDlgOpenTransfer::KDlgOpenTransfer(QWidget *parent, const char *name) :
    // don't enable WDestructiveClose
    KDialogBase(parent, name, true, i18n("Open Transfer"), Ok|Cancel, Ok) {
    initDialog();
    actionButton(Ok)->setAutoDefault(false);
 }
 
-KDlgOpenTransfer::~KDlgOpenTransfer() 
+KDlgOpenTransfer::~KDlgOpenTransfer()
 {
 }
 
-KMagoDoc * KDlgOpenTransfer::doc() const 
+KMagoDoc * KDlgOpenTransfer::doc() const
 {
    return _doc;
 }
 
-void KDlgOpenTransfer::initDialog() 
+void KDlgOpenTransfer::initDialog()
 {
    QWidget *page = new QWidget(this);
    page->setMinimumWidth(300);
@@ -58,10 +58,10 @@ void KDlgOpenTransfer::initDialog()
 
    QGroupBox *gbox = new QGroupBox(1, Horizontal, page);
    l->addWidget(gbox);
-  
+
    QLabel *lbl = new QLabel(i18n("URL to download:"), gbox,"LblURL");
    cmbURL = new KComboBox(true, gbox,"CmbURL");
-   connect(cmbURL, SIGNAL(activated(const QString&)), 
+   connect(cmbURL, SIGNAL(activated(const QString&)),
 	   this, SLOT(slotReadURL(const QString&)));
 
    lbl = new QLabel(i18n("Write to file:"), gbox,"LblFile");
@@ -83,8 +83,8 @@ void KDlgOpenTransfer::initDialog()
    box->setStretchFactor(cmbType, 1);
 }
 
-void KDlgOpenTransfer::init(KMagoDoc *doc, KTManager mngr, const KURL &rmt, 
-			    const KURL &lcl) 
+void KDlgOpenTransfer::init(KMagoDoc *doc, KTManager mngr, const KURL &rmt,
+			    const KURL &lcl)
 {
    _doc = doc;
    _mngr = mngr.isNull() ? doc->currentManager() : mngr;
@@ -104,13 +104,13 @@ void KDlgOpenTransfer::init(KMagoDoc *doc, KTManager mngr, const KURL &rmt,
    }
 }
 
-bool KDlgOpenTransfer::getOpenTransfer(KMagoDoc *doc, KTManager &mngr, 
-				       KURL &rmt, KURL &lcl, int &type) 
+bool KDlgOpenTransfer::getOpenTransfer(KMagoDoc *doc, KTManager &mngr,
+				       KURL &rmt, KURL &lcl, int &type)
 {
    if (dlg == 0)
       dlg = new KDlgOpenTransfer(kapp->mainWidget(), "KDlgOpenTransfer");
    dlg->init(doc, mngr, rmt, lcl);
-   if (dlg->exec() == Accepted) 
+   if (dlg->exec() == Accepted)
    {
       mngr = dlg->_mngr;
       rmt = dlg->_rmt;
@@ -146,29 +146,20 @@ KURL url(u);
 }
 */
 
-/** correct file name */
-QString KDlgOpenTransfer::correctFile(const QString &f) 
+QString KDlgOpenTransfer::correctFile(const QString &f)
 {
    QFileInfo file(_mngr.getDownloadDir(), f);
-   if (doc()->getOpenFlags() & FLG_FILE_AUTO_ENCODE) 
-   {
-      QString filename = file.fileName();
-      int p;
-      while ((p = filename.find(' ')) != -1) 
-      {
-	 filename[p] = '_';
-      }
-      file.setFile(_mngr.getDownloadDir(), filename);
-   }
+   if (doc()->getOpenFlags() & FLG_FILE_AUTO_ENCODE)
+      file.setFile(_mngr.getDownloadDir(), encodeFileName(file.fileName()));
    return file.absFilePath();
 }
 
-void KDlgOpenTransfer::updateType() 
+void KDlgOpenTransfer::updateType()
 {
    cmbType->clear();
    _typeList.clear();
    KObject::List lst = _mngr.globals();
-   for(KObject::List::Iterator i = lst.begin(); i != lst.end(); ++i) 
+   for(KObject::List::Iterator i = lst.begin(); i != lst.end(); ++i)
    {
       cmbType->insertItem(KObject::typeStr((*i).type()));
       _typeList += (*i).type();
@@ -188,14 +179,14 @@ void KDlgOpenTransfer::updateType()
     }
 */
 
-void KDlgOpenTransfer::slotSelectManager(int i) 
+void KDlgOpenTransfer::slotSelectManager(int i)
 {
    _mngr = doc()->manager().itemAt(i).toTManager();
    updateType();
    slotReadURL(_rmt.url());
 }
 
-void KDlgOpenTransfer::slotOk() 
+void KDlgOpenTransfer::slotOk()
 {
    if (cmbURL->currentText() == "" || cmbFile->url() == "")
       return;
@@ -203,8 +194,8 @@ void KDlgOpenTransfer::slotOk()
    _lcl.setPath(cmbFile->url());
    _type = _typeList[cmbType->currentItem()];
    //kdDebug(D_VIE) << name() << ": URL=<" << _rmt.url() << "> =>" << _rmt.isMalformed() << " FILE=<" << _lcl.path() << ">" << endl;
-   if (_rmt.path().isEmpty() || _rmt.isMalformed() 
-       || _lcl.path().isEmpty() 
+   if (_rmt.path().isEmpty() || _rmt.isMalformed()
+       || _lcl.path().isEmpty()
        || !QDir::current().exists(_lcl.directory())
        || (doc()->getOpenFlags() & FLG_FILE_FORCE_ENCODE
 	   && _lcl.path().find(' ') != -1)
