@@ -4,7 +4,7 @@
     begin                : Mon Sep 18 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.44 $
+    revision             : $Revision: 1.46 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -56,10 +56,13 @@
 
 
 const char KMagoApp::IDS_STATUS_DEFAULT[] = "Ready.";
+int KMagoApp::_appCnt;
 
 KMagoApp::KMagoApp(bool restored)
+   : KMainWindow(), DCOPObject(QCString().sprintf("App-%d", _appCnt)),
+     _id(_appCnt)
 {
-   setName(QString("App-%1").arg(memberList->count()));
+   setName(QString("App-%1").arg(_appCnt++));
 
    initActions();
    initStatusBar();
@@ -463,6 +466,14 @@ void KMagoApp::readProperties(KConfig* config)
    view()->initView();
 }
 
+void KMagoApp::saveGlobalProperties(KConfig *config)
+{
+   if (isSingleDoc())
+      config->writeEntry("SingleDoc", true);
+   if (isUniqueApp())
+      config->writeEntry("UniqueApp", true);
+}
+
 void KMagoApp::applySettings(KConfig *config, bool fromSession)
 {
    kdDebug(D_INI) << name() << ": apply settings" << endl;
@@ -785,6 +796,215 @@ void KMagoApp::resizeEvent(QResizeEvent *event)
    statusBar()->setItemFixed(STATUS_MSG, _statusMsgWidth);
 }
 
+////////////// DCOP INTERFACE KMagoAppIface
+
+int KMagoApp::appId() const
+{
+   return id();
+}
+
+QString KMagoApp::title() const
+{
+   return doc()->title();
+}
+
+bool KMagoApp::isClosed() const
+{
+   return doc()->isClosed();
+}
+
+bool KMagoApp::isTmp() const
+{
+   return doc()->isTmp();
+}
+
+bool KMagoApp::isIdle() const
+{
+   return doc()->manager().isIdle();
+}
+
+bool KMagoApp::isRunning() const
+{
+   return doc()->manager().isRunning();
+}
+
+void KMagoApp::openNewDocument()
+{
+   slotFileNew();
+}
+
+void KMagoApp::openDocument(const QString &filename)
+{
+   //QDir::setCurrent(QFileInfo(filename).dirPath());
+   if (!doc()->open(filename))
+      slotFileNew();
+}
+
+void KMagoApp::saveDocumentAs(const QString &filename)
+{
+   doc()->saveAs(filename);
+}
+
+void KMagoApp::closeApp()
+{
+   slotFileClose();
+}
+
+bool KMagoApp::getDownloadLock() const
+{
+   return doc()->manager().downloadLock();
+}
+
+bool KMagoApp::getExitOnIdle() const
+{
+   return doc()->exitOnIdle();
+}
+
+bool KMagoApp::getExecuteOnIdle() const
+{
+   return doc()->executeOnIdle();
+}
+
+int KMagoApp::getCurrentManager() const
+{
+   if (doc()->currentManager().isNull())
+      return 0;
+   return doc()->currentManager().id();
+}
+
+void KMagoApp::setCurrentManager(int id)
+{
+   KTManager obj = doc()->manager().itemFindId(id).toTManager();
+   if (obj.isNull())
+      return;
+   doc()->setCurrentManager(obj);
+}
+
+int KMagoApp::getCurrentTransfer() const
+{
+   if (doc()->currentTransfer().isNull())
+      return 0;
+   return doc()->currentTransfer().id();
+}
+
+void KMagoApp::setCurrentTransfer(int id)
+{
+   KTransfer obj = doc()->manager().itemSearch(id).toTransfer();
+   if (obj.isNull())
+      return;
+   doc()->setCurrentManager(obj.container().toTManager());
+   doc()->setCurrentTransfer(obj);
+}
+
+void KMagoApp::addTransfer(const QString &url, int mode)
+{
+   doc()->addTransfer(url, KTManager::null(), mode);
+}
+
+void KMagoApp::addTransferTo(int id, const QString &url, int mode)
+{
+   KTManager obj = doc()->manager().itemFindId(id).toTManager();
+   if (obj.isNull())
+      return;
+   doc()->addTransfer(url, obj, mode);
+}
+
+void KMagoApp::removeObject(int id)
+{
+   KObject obj = doc()->manager().itemSearch(id);
+   if (obj.isNull() || obj == doc()->manager())
+      return;
+   obj.container().itemRemove(obj);
+}
+
+void KMagoApp::transferStart(int id)
+{
+   KTransfer t = doc()->manager().itemSearch(id).toTransfer();
+   if (t.isNull() || t.isRunning())
+      return;
+   t.start();
+}
+
+void KMagoApp::transferKill(int id)
+{
+   KTransfer t = doc()->manager().itemSearch(id).toTransfer();
+   if (t.isNull() || !t.isRunning())
+      return;
+   t.kill();
+}
+
+void KMagoApp::managerKill(int id)
+{
+   KTManager m = doc()->manager().itemFindId(id).toTManager();
+   if (m.isNull() || !m.isRunning())
+      return;
+   m.kill();
+}
+
+void KMagoApp::kill()
+{
+   doc()->manager().kill();
+}
+
+QValueList<int> KMagoApp::managers() const
+{
+   QValueList<int> lst;
+   for (KCntIterator it(doc()->manager()); !it.current().isNull(); ++it)
+      lst << it.current().id();
+   return lst;
+}
+
+QValueList<int> KMagoApp::transfers(int id) const
+{
+   QValueList<int> lst;
+   KTManager m = doc()->manager().itemFindId(id).toTManager();
+   if (m.isNull())
+      return lst;
+   for (KCntIterator it(m); !it.current().isNull(); ++it)
+      lst << it.current().id();
+   return lst;
+}
+
+bool KMagoApp::hasObject(int id) const
+{
+   return !doc()->manager().itemSearch(id).isNull();
+}
+
+QStringList KMagoApp::managersString() const
+{
+   QStringList lst;
+   for (KCntIterator it(doc()->manager()); !it.current().isNull(); ++it)
+      lst << QString::number(it.current().id());
+   return lst;
+}
+
+QStringList KMagoApp::transfersString(int id) const
+{
+   QStringList lst;
+   KTManager m = doc()->manager().itemFindId(id).toTManager();
+   if (m.isNull())
+      return lst;
+   for (KCntIterator it(m); !it.current().isNull(); ++it)
+      lst << QString::number(it.current().id());
+   return lst;
+}
+
+QString KMagoApp::transferRemote(int id) const
+{
+   KTransfer t = doc()->manager().itemSearch(id).toTransfer();
+   if (t.isNull())
+      return QString::null;
+   return t.remote().prettyURL();
+}
+
+QString KMagoApp::transferLocal(int id) const
+{
+   KTransfer t = doc()->manager().itemSearch(id).toTransfer();
+   if (t.isNull())
+      return QString::null;
+   return t.local().path();
+}
+
 /////////////////////////////////////////////////////////////////////
 // SLOT IMPLEMENTATION
 /////////////////////////////////////////////////////////////////////
@@ -816,7 +1036,7 @@ void KMagoApp::slotFileOpen()
       KFileDialog::getOpenFileName(QDir::currentDirPath(),
 				   i18n("*|All files"),
 				   this, i18n("Open File..."));
-   QDir::setCurrent(QFileInfo(fileToOpen).dirPath());
+   //QDir::setCurrent(QFileInfo(fileToOpen).dirPath());
    if(fileToOpen.isEmpty())
       return;
    if (!doc()->open(fileToOpen))
