@@ -4,7 +4,7 @@
     begin                : Mon Sep 18 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.27 $
+    revision             : $Revision: 1.29 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -59,14 +59,12 @@ void KMagoDoc::NotifyChange::operator()(const KObject obj) const
 /////////////////////////////////////////////////////////////////
 
 KMagoDoc::KMagoDoc(KMagoApp *parent, const char *name)
-   : QObject(parent, name), _app(parent), _title(i18n("Untitled")), _tmp(false),
-_exitOnIdle(false), _firstIdle(true), _executeOnIdle(false)
+   : QObject(parent, name),
+     _app(parent), _title(i18n("Untitled")),
+     _tmp(false), _exitOnIdle(false), _firstIdle(true),
+     _executeOnIdle(false)
 {
    KObject::initFactory();
-   //_timerUpd = new QTimer(this);
-   //_timerSave = new QTimer(this);
-   //_timerTStart = new QTimer(this);
-   //getDocument()->newDocument();
    connect(&_timerUpd, SIGNAL(timeout()), SLOT(slotUpdate()));
    connect(&_timerSave, SIGNAL(timeout()), SLOT(slotSave()));
    connect(&_timerTStart, SIGNAL(timeout()), SLOT(slotTransferStart()));
@@ -195,7 +193,6 @@ void KMagoDoc::saveConfig(KConfig *config)
    config->writeEntry("Transfer Start Time", _cfg_TStartTime);
    config->writeEntry("Expert Mode", _cfg_expertMode);
    //config->writeEntry("ExitOnIdle", _cfg_exitOnIdle);
-   config->writeEntry("Start Mode", _cfg_startMode);
    config->writeEntry("Load Last Doc", _cfg_loadLastDoc);
    config->writeEntry("List On Drop", _cfg_listOnDrop);
    config->writeEntry("EnableNotify", _cfg_enableNotify);
@@ -212,13 +209,13 @@ void KMagoDoc::saveConfig(KConfig *config)
 void KMagoDoc::readConfig(KConfig* config)
 {
    kdDebug(D_INI) << name() << ": read config" << endl;
-   _cfg_openFlags = config->readNumEntry("Open Flags", 0);
+   _cfg_openFlags = config->readNumEntry("Open Flags",
+					 FLG_PROMPT | FLG_START_PROMPT);
    _cfg_expertMode = config->readBoolEntry("Expert Mode", false);
    //_cfg_exitOnIdle = false; //config->readBoolEntry("ExitOnIdle", false);
    _cfg_updateTime = config->readNumEntry("Update Time", 2000);
    _cfg_saveTime = config->readNumEntry("Save Time", 10);
    _cfg_TStartTime = config->readNumEntry("Transfer Start Time", 2000);
-   _cfg_startMode = config->readNumEntry("Start Mode", START_PROMPT);
    _cfg_loadLastDoc = config->readBoolEntry("Load Last Doc", true);
    _cfg_listOnDrop = config->readBoolEntry("List On Drop", false);
    _lastUsed = config->readEntry("Last Used Document", "");
@@ -259,8 +256,9 @@ void KMagoDoc::saveState()
 
 void KMagoDoc::reloadState()
 {
-   QListIterator<KMainWindow> it(*KMainWindow::memberList);
-   for (it.toFirst(); it.current(); ++it)
+
+   for (QListIterator<KMainWindow> it(*KMainWindow::memberList); it.current();
+	++it)
    {
       dynamic_cast<KMagoApp*>(it.current())->doc()->loadState(true);//FIXME so to not reapply window settings??
    }
@@ -276,22 +274,27 @@ int KMagoDoc::isDuplicate(const KURL &rmt, const KURL &lcl)
 	 KTransfer t = itt.current().toTransfer();
 	 if (t.remote() == rmt)
 	    return 1;
-	 if (t.local() == lcl)
+	 if (t.local().path() == lcl.path())
 	    return 2;
       }
    }
    return 0;
 }
 
-void KMagoDoc::addTransfer(const KURL &u, KTManager mngr)
+void KMagoDoc::addTransfer(const KURL &u, KTManager mngr, int mode)
 {
    if (mngr.isNull())
       mngr = currentManager();
+   if (mode == FLG_DEFAULT)
+      mode = getOpenFlags();
    int type = mngr.getDefaultType();
    KURL rmt = u;
    KURL lcl;
    lcl.setPath(QFileInfo(mngr.getDownloadDir(), rmt.fileName()).absFilePath());
-   if ((rmt.path().isEmpty() || !(getOpenFlags() & FLG_NO_PROMPT))
+   if (mode & (FLG_FILE_AUTO_ENCODE | FLG_FILE_FORCE_ENCODE))
+      lcl.setFileName(encodeFileName(lcl.fileName()));
+
+   if ((rmt.path().isEmpty() || (mode & FLG_PROMPT))
        && !KDlgOpenTransfer::getOpenTransfer(this, mngr, rmt, lcl, type))
       return;
    KTransfer glb = mngr.findGlobal(type).toTransfer();
@@ -323,13 +326,13 @@ void KMagoDoc::addTransfer(const KURL &u, KTManager mngr)
       {
       case 1:
 	 KMessageBox::sorry(mainWindow(),
-			    i18n("File " + lcl.path() + " in use"),
-			    i18n("File in use"), false);
+			    i18n("Url " + rmt.url() + " in use"),
+			    i18n("Url in use"), false);
 	 return;
       case 2:
 	 KMessageBox::sorry(mainWindow(),
-			    i18n("Url " + rmt.url() + " in use"),
-			    i18n("Url in use"), false);
+			    i18n("File " + lcl.path() + " in use"),
+			    i18n("File in use"), false);
 	 return;
       }
    // checking for file recover
@@ -398,17 +401,18 @@ void KMagoDoc::addTransfer(const KURL &u, KTManager mngr)
       }
    } // end else
    // evaluting start mode
-   int start = getStartMode();
-   if (start == START_PROMPT)
+   bool start = false;
+   if (mode & FLG_START_PROMPT)
    {
       switch (promptStartMode(i18n("Select a start mode"),
-			      i18n("Transfer:\n") + rmt.url() + i18n("\nto ") + file))
+			      i18n("Transfer:\n") + rmt.url() + i18n("\nto ") +
+			      file))
       {
       case KMessageBox::Yes:
-	 start = START_NOW;
+	 start = true;
 	 break;
       case KMessageBox::No:
-	 start = START_NO;
+	 start = false;
 	 break;
       case KMessageBox::Cancel:
 	 return;
@@ -416,10 +420,12 @@ void KMagoDoc::addTransfer(const KURL &u, KTManager mngr)
 	 kdFatal(D_INI) << name() << ": addTransfer PROMPT ERROR" << endl;
       }
    }
+   else
+      start = (mode & FLG_START_NOW);
    // add transfer
    mainView()->managerAddRecent->addURL(rmt);
    KTransfer t = mngr.itemNew(type, rmt, lcl);
-   if (start == START_NOW)
+   if (start)
       t.start();
 }
 
@@ -547,12 +553,12 @@ void KMagoDoc::updateView(KObject obj)
    kdDebug(D_VIE) << name() << ": mod obj " << obj.name() << " " << obj.modString() << endl;
    if (obj.isMod(MDI_MESSAGE))
       mainView()->slotStatusHelpMsg(obj.message());
-   else if (obj.isMod(MDI_ERROR))
+   if (obj.isMod(MDI_FATAL))
    {
       // fatal error, open and fill bug report
       kdDebug(D_RUN) << name() << " catch fatal error of " << obj.name() << endl;
       KMagoBugReport *bugrep =
-	 new KMagoBugReport(mainWindow(), true, kapp->aboutData());
+	 new KMagoBugReport(mainWindow(), false, kapp->aboutData());
       bugrep->appendLine(obj.message());
       bugrep->show();
    }
@@ -574,6 +580,7 @@ void KMagoDoc::updateView(KObject obj)
 	    sh.start(KProcess::DontCare, KProcess::NoCommunication);
 	    _firstIdle = false;
 	 }
+
 	 // if is idle and exitOnIdle is true, exit
 	 if (exitOnIdle() && manager().isIdle())
 	 {
@@ -661,7 +668,7 @@ void KMagoDoc::updateView(KObject obj)
 	 {
 	    mainView()->managerKillAll->setEnabled(true);
 	 }
-	 else if (obj.isMod(MDI_STOP))
+	 if (obj.isMod(MDI_STOP))
 	 {
 	    mainView()->managerKillAll->setEnabled(false);
 	 }
@@ -687,16 +694,20 @@ void KMagoDoc::updateView(KObject obj)
       if (obj.isMod(MDI_START))
       {
 	 if (getEnableNotify())
-	    KNotifyClient::event("transferStart", i18n("transfer start: ") + obj.toTransfer().remote().prettyURL());
+	    KNotifyClient::event("transferStart", i18n("transfer start: ") +
+				 obj.toTransfer().remote().prettyURL());
 	 if (getAutoProgress() && mainView()->_progressWnds[obj.id()] == 0)
 	    mainView()->openTransferProgress(obj.toTransfer());
       }
       if (obj.isMod(MDI_STOP))
       {
 	 if (getEnableNotify() && obj.toTransfer().state() == TRN_END_ERROR)
-	    KNotifyClient::event("transferError", i18n("transfer error: ") + obj.toTransfer().remote().prettyURL());
+	    KNotifyClient::event("transferError", i18n("transfer error: ") +
+				 obj.toTransfer().remote().prettyURL());
 	 if (getEnableNotify() && obj.toTransfer().isComplete())
-	    KNotifyClient::event("transferComplete", i18n("transfer complete: ") + obj.toTransfer().remote().prettyURL());
+	    KNotifyClient::event("transferComplete",
+				 i18n("transfer complete: ") +
+				 obj.toTransfer().remote().prettyURL());
 	 if (getAutoProgress() && obj.toTransfer().isComplete()
 	     && mainView()->_progressWnds[obj.id()] != 0)
 	    mainView()->_progressWnds[obj.id()]->close();
