@@ -4,7 +4,7 @@
     begin                : Wed Oct 18 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.18 $
+    revision             : $Revision: 1.19 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,31 +26,31 @@ const char KMManagerImpl::DOCID[] = "MManager";
 const char KMManagerImpl::DOCTYPE[] = "<!DOCTYPE MManager >";
 
 
-KMManagerImpl::KMManagerImpl() 
+KMManagerImpl::KMManagerImpl()
    : KRootContainerImpl(TYP_MMANAGER), _downloadLock(false), _idle(false)
 {
 }
 
-KObjectImpl * KMManagerImpl::clone() const 
+KObjectImpl * KMManagerImpl::clone() const
 {
    kdFatal(D_INI) << ": unable to clone root" << endl;
    return 0;
 }
 
-const KMManagerImpl * KMManagerImpl::global() const 
+const KMManagerImpl * KMManagerImpl::global() const
 {
-   const KMManagerImpl *globalmngr = 
+   const KMManagerImpl *globalmngr =
       dynamic_cast<const KMManagerImpl*>(KObjectImpl::global());
    kdFatal( globalmngr != KObjectImpl::global(), D_INI) << name() << ": global has wrong type" << endl;
-   return globalmngr; 
+   return globalmngr;
 }
 
-KTManagerImpl * KMManagerImpl::itemNew(const QString &title) 
+KTManagerImpl * KMManagerImpl::itemNew(const QString &title)
 {
    QString objDocId = KFactoryImpl::factory()->docId(TYP_TMANAGER);
    QString objTypeStr = KFactoryImpl::factory()->typeStr(TYP_TMANAGER);
    int objId = assignId();
-   QString objStrId = 
+   QString objStrId =
       QString("%1-%2").arg(objTypeStr).arg(objId);
    kdDebug(D_INI) << name() << ": item new: " << objStrId << endl;
    QDomElement e = findDefault(TYP_TMANAGER)->dom().cloneNode(false).toElement();
@@ -65,7 +65,7 @@ KTManagerImpl * KMManagerImpl::itemNew(const QString &title)
    return dynamic_cast<KTManagerImpl*>(itemLoad(e));
 }
 
-void KMManagerImpl::loadData() 
+void KMManagerImpl::loadData()
 {
    dom().setAttribute("ItemType", TYP_TMANAGER_T);
    KRootContainerImpl::loadData();
@@ -76,23 +76,23 @@ void KMManagerImpl::loadData()
       setMaxBandwidth(0);
       setMaxConnection(3);
    }
-   _downloadLock = dom().attribute("DownloadLock", 
+   _downloadLock = dom().attribute("DownloadLock",
 				   QString::number(true)).toInt();
-   _cfg_maxBandwidth = dom().attribute("MaxBandwidth", 
+   _cfg_maxBandwidth = dom().attribute("MaxBandwidth",
 				       QString::number(0)).toInt();
-   _cfg_maxConnection = dom().attribute("MaxOpenConnection", 
+   _cfg_maxConnection = dom().attribute("MaxOpenConnection",
 					QString::number(3)).toInt();
    _bandwidth = 0;
    _mediumBandwidth = 0;
 }
 
-void KMManagerImpl::runPeriodically() 
+void KMManagerImpl::runPeriodically()
 {
    kdFatal(useGlobal() == true) << "normal = " << isNormal() << endl;
    KRootContainerImpl::runPeriodically();
 }
 
-void KMManagerImpl::startPendingTransfer() 
+void KMManagerImpl::startPendingTransfer()
 {
    KTransferImpl *best = 0;
    if (((_mediumBandwidth != 0 || _bandwidth != 0) && itemActiveCount() == 0)
@@ -121,7 +121,7 @@ void KMManagerImpl::startPendingTransfer()
    }
    setIdle(!(isRunning() || (!downloadLock() && runInFuture)));
    kdDebug(D_RUN) << name() << ": idle " << isIdle() << endl;
-   if (!downloadLock() && best != 0 
+   if (best != 0 && (!downloadLock() || best->needRestart())
        && (!getMaxBandwidth() || mediumBandwidth() < getMaxBandwidth())
        && (!getMaxConnection() || trActive < getMaxConnection()))
       best->start();
@@ -149,7 +149,7 @@ void KMManagerImpl::setIdle(bool l)
 
 //////////// config entries
 
-int KMManagerImpl::getMaxConnection() const 
+int KMManagerImpl::getMaxConnection() const
 {
    return useGlobal() ? global()->getMaxConnection() :_cfg_maxConnection;
 }
@@ -165,7 +165,7 @@ void KMManagerImpl::setMaxConnection(int m)
    }
 }
 
-int KMManagerImpl::getMaxBandwidth() const 
+int KMManagerImpl::getMaxBandwidth() const
 {
    return useGlobal() ? global()->getMaxBandwidth() :_cfg_maxBandwidth;
 }
