@@ -4,10 +4,8 @@
     begin                : Thu Oct 19 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.2 $
- ***************************************************************************/
-
-/***************************************************************************
+    revision             : $Revision: 1.5 $
+ ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -27,13 +25,18 @@
 
 
 /**
-  *@author Sergio Moretti
-  */
+ * @short Abstract base class for notifier objects, as in Command Pattern.
+ * 
+ * @author Sergio Moretti
+ *
+ * @version $Id: knotifychange.h,v 1.5 2001/03/18 16:31:03 sergio Exp $
+ */
 
-class KNotifyChange {
+class KNotifyChange 
+{
 public:
-  virtual ~KNotifyChange() {}
-  virtual void operator()(const KObject source, ModType type) const = 0;
+   virtual ~KNotifyChange() {}
+   virtual void operator()(const KObject source) const = 0;
 };
 
 #endif
