@@ -4,7 +4,7 @@
     begin                : Mon Oct 16 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.14 $
+    revision             : $Revision: 1.15 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -27,14 +27,14 @@
 const char KObjectImpl::DOCID[] = "Object";
 const char KObjectImpl::DOCTYPE[] = "<!DOCTYPE Object >";
 
-KObjectImpl::KObjectImpl(int type) 
-   : QObject(), _root(0), _container(0), _id(0), _global(0), 
-     _cfg_global(false), _type(type), _modState(MDI_NUM), _priority(-1) 
+KObjectImpl::KObjectImpl(int type)
+   : QObject(), _root(0), _container(0), _id(0), _global(0),
+     _cfg_global(false), _type(type), _modState(MDI_NUM), _priority(-1)
 {
    resetBits(_modState);
 }
 
-KObjectImpl::~KObjectImpl() 
+KObjectImpl::~KObjectImpl()
 {
    kdDebug(D_INI) << name() << ": destroy" << endl;
    //kdFatal(isModified(MOD_ALL)) << name() << ": destroy modified " << _modified << endl;
@@ -43,7 +43,7 @@ KObjectImpl::~KObjectImpl()
    dom().clear();
 }
 
-int KObjectImpl::cmpPriority(const KObjectImpl *obj) const 
+int KObjectImpl::cmpPriority(const KObjectImpl *obj) const
 {
    // root can't be compared
    kdFatal(isRoot() || obj->isRoot()) << name() << ": cmpPriority with root" << endl;
@@ -52,7 +52,7 @@ int KObjectImpl::cmpPriority(const KObjectImpl *obj) const
    if ( p1 != p2 )
       return p1 > p2 ? 1 : -1;
    // if p1 == p2
-   switch (container()->getPriorityPolicy()) 
+   switch (container()->getPriorityPolicy())
    {
    case PRI_FIFO:
       return cmpPriorityFifo(obj);
@@ -88,9 +88,9 @@ int KObjectImpl::cmpPriorityLong(const KObjectImpl *) const
    return 0;
 }
 
-void KObjectImpl::emitMod() 
+void KObjectImpl::emitMod()
 {
-   if (isMods(ANYMOD)) // && obj == 0 && !isRoot()) 
+   if (isMods(ANYMOD)) // && obj == 0 && !isRoot())
    {
       //kdDebug(D_RUN) << name() << ": modified = " << QString("%1").arg(_modState, 0, 16) << " prop = " << QString("%1").arg(prop, 0, 16) << endl;
       root()->signalMod(this);
@@ -99,17 +99,17 @@ void KObjectImpl::emitMod()
 
 bool KObjectImpl::isRoot() const
 {
-   return root() == this; 
+   return root() == this;
 }
 
-void KObjectImpl::load(KContainerImpl *cont, const QDomElement &e) 
+void KObjectImpl::load(KContainerImpl *cont, const QDomElement &e)
 {
    kdDebug(D_INI) << e.attribute("Name") << ": load" << endl;
    if (e.tagName() != docId()
        || !e.hasAttribute("Version")
        || !e.hasAttribute("Id")
        || !e.hasAttribute("Name")
-       || !e.hasAttribute("Type")) 
+       || !e.hasAttribute("Type"))
    {
       /* throw */
       new DomError(name(), i18n("load: malformed document"), e);
@@ -128,7 +128,7 @@ void KObjectImpl::load(KContainerImpl *cont, const QDomElement &e)
    //<< dom().ownerDocument().toString() << "END DOM" << endl;
 }
 
-void KObjectImpl::loadData() 
+void KObjectImpl::loadData()
 {
    kdDebug(D_INI) << name() << ": Object loaddata" << endl;
    if (!dom().hasAttribute("GlobalCfg"))
@@ -139,51 +139,51 @@ void KObjectImpl::loadData()
    {
       dom().setAttribute("Priority", 0);
    }
-   _cfg_global = dom().attribute("GlobalCfg", 
+   _cfg_global = dom().attribute("GlobalCfg",
 				 QString::number(!isGlobal())).toInt();
    _priority = dom().attribute("Priority", QString::number(0)).toInt();
 }
 
-int KObjectImpl::prioritySum() const 
-{ 
+int KObjectImpl::prioritySum() const
+{
    return priority() + (isRoot() ? 0 : container()->prioritySum());
 }
 
-void KObjectImpl::runPeriodically() 
+void KObjectImpl::runPeriodically()
 {
    // refresh the object view
    emitMod();
 }
 
-void KObjectImpl::setGlobal(bool g) 
-{ 
-   if (_cfg_global != g) 
+void KObjectImpl::setGlobal(bool g)
+{
+   if (_cfg_global != g)
    {
-      _cfg_global = g; 
+      _cfg_global = g;
       dom().setAttribute("GlobalCfg", _cfg_global);
-      setMod(MDI_GLOBAL); 
+      setMod(MDI_GLOBAL);
       root()->setModified();
-   } 
+   }
 }
 
-void KObjectImpl::setPriority(int p) 
-{ 
+void KObjectImpl::setPriority(int p)
+{
    if (_priority != p)
    {
       _priority = p;
       dom().setAttribute("Priority", _priority);
-      setMod(MDI_PRIORITY); 
+      setMod(MDI_PRIORITY);
       root()->setModified();
    }
-   
+
 }
 
-void KObjectImpl::setMessage(const QString &msg) 
-{ 
+void KObjectImpl::setMessage(const QString &msg)
+{
    // temp data
    if (_msg != msg)
    {
-      _msg = msg; 
+      _msg = msg;
       setMod(MDI_MESSAGE);
       root()->setModified();
    }
@@ -194,12 +194,11 @@ void KObjectImpl::setFatalError(bool v)
    if (_fatalError != v)
    {
       _fatalError = v;
-      setMod(MDI_FATAL);
       root()->setModified();
    }
 }
 
-QDomDocument KObjectImpl::toDom() const 
+QDomDocument KObjectImpl::toDom() const
 {
    QDomDocument doc(DOC);
    QByteArray data;
@@ -214,12 +213,12 @@ QDomDocument KObjectImpl::toDom() const
    return doc;
 }
 
-QString KObjectImpl::typeStr() const 
+QString KObjectImpl::typeStr() const
 {
    return KFactoryImpl::factory()->typeStr(type());
 }
 
-void KObjectImpl::waitForKill() 
+void KObjectImpl::waitForKill()
 {
    QTime timeout;
    timeout.start();
@@ -227,7 +226,7 @@ void KObjectImpl::waitForKill()
       kapp->processEvents();
 
    kdFatal(isRunning(), D_RUN) << name() << ": unable to complete kill op" << endl;
-}   
+}
 
 bool KObjectImpl::isMod(ModIndex p) const
 {
@@ -239,8 +238,8 @@ bool KObjectImpl::isMods(const ModFlags &f) const
    return mapBits(f, _modState);
 }
 
-void KObjectImpl::setMod(ModIndex p) 
-{ 
+void KObjectImpl::setMod(ModIndex p)
+{
    setBit(p, _modState);
    /*
    if (!isRoot())
@@ -249,8 +248,8 @@ void KObjectImpl::setMod(ModIndex p)
    */
 }
 
-void KObjectImpl::setMods(const ModFlags &f) 
-{ 
+void KObjectImpl::setMods(const ModFlags &f)
+{
    orBits(f, _modState);
    /*
    if (!isRoot())
