@@ -4,7 +4,7 @@
     begin                : Wed Dec 20 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.13 $
+    revision             : $Revision: 1.14 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -372,7 +372,7 @@ void KTManagerListView::applySettings(KConfig *config)
    _viewError->setChecked(config->readBoolEntry("TManagerListView Error", true));
    _viewStateStr->setChecked(config->readBoolEntry("TManagerListView StateStr",
 	 					   true));
-   _sortByCol = config->readNumEntry("TManagerListView SortBy", 0);
+   _sortByCol = config->readNumEntry("TManagerListView SortBy", 11); // by ID
    _sortDir = config->readBoolEntry("TManagerListView SortDir", true);
 }
 
@@ -547,12 +547,17 @@ void KTManagerListItem::update()
    switch (t.state())
    {
    case TRN_READY:
-   case TRN_END_READY:
       if (t.priority() > 0)
 	 setPixmap(0, SmallIcon("run"));
       else
 	 setPixmap(0, SmallIcon("lock"));
       break;
+   case TRN_END_READY:
+      if (t.priority() > 0)
+	 setPixmap(0, SmallIcon("redo"));
+      else
+	 setPixmap(0, SmallIcon("lock"));
+      break;
    case TRN_START:
       setPixmap(0, SmallIcon("connect_no"));
       break;
@@ -563,9 +568,11 @@ void KTManagerListItem::update()
       setPixmap(0, SmallIcon("connect_established"));
       break;
    case TRN_END_OK:
-   case TRN_END_ERROR:
       setPixmap(0, SmallIcon("player_pause"));
       break;
+   case TRN_END_ERROR:
+      setPixmap(0, SmallIcon("fileclose"));
+      break;
    case TRN_END_KILL:
       setPixmap(0, SmallIcon("player_stop"));
       break;
