@@ -4,7 +4,7 @@
     begin                : Tue Oct 17 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.24 $
+    revision             : $Revision: 1.26 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,7 +33,7 @@ const char KTransferImpl::DOCTYPE[] = "<!DOCTYPE Transfer >";
 KTransferImpl::KTransferImpl(int type)
    :  KObjectImpl(type), _state(TRN_START), _rsmState(RSM_UNKNOWN), _resumed(0),
       _lastBytesRead(0), _mediumBandwidth(0), _bandwidth(0), _killed(false),
-      _retry(0), _checkResume(0)
+      _retry(0), _checkResume(0), _restart(false)
 {
    _lastSampleTime.setHMS(0, 0, 0);
    _timeStart.setHMS(0, 0, 0);
@@ -178,7 +178,7 @@ QString KTransferImpl::stateStr(TrnState state)
    case TRN_END_KILL:
       return i18n("Killed");
    case TRN_END_READY:
-      return i18n("Resumable");
+      return i18n("Restartable");
    }
    kdFatal(D_RUN) << "stateStr: unknown state " << state << endl;
    return QString::null;
@@ -322,7 +322,7 @@ bool KTransferImpl::isRunnable(bool automatic) const
        || ( state() == TRN_END_READY // resuming
 	    && getAutoResume()
 	    && (isResumable() || rsmState() == RSM_UNKNOWN
-		|| rsmState() == RSM_CHECKFAIL)
+		|| rsmState() == RSM_CHECKFAIL || partial() == 0)
 	    && ((!getMaxResume() || resumed() < getMaxResume())
 		|| (!getMaxResume() || resumed() == getMaxResume()
 		    && retry() < getMaxRetry())))
@@ -335,7 +335,7 @@ bool KTransferImpl::isRunnableInFuture(bool dLock, bool automatic) const
 	   && ((!dLock && isRunnable(automatic)) // runnable now
 	       || (getAutoResume()
 		   && (isResumable() || rsmState() == RSM_UNKNOWN
-		       || rsmState() == RSM_CHECKFAIL)
+		       || rsmState() == RSM_CHECKFAIL || partial() == 0)
 		   && (state() == TRN_END_OK || state() == TRN_END_ERROR)
 		   && ((!getMaxRetry() || retry() < getMaxRetry())
 		       || (!dLock && !getMaxResume()
@@ -357,8 +357,10 @@ void KTransferImpl::raiseFatalError()
 	 log << line << endl;
       }
       _logFile.close();
-      setMessage(msg);
+      setMessage(message() + msg);
    }
+   //setFatalError(false);
+   setMod(MDI_FATAL);
    // refresh view
    emitMod();
 }
@@ -450,6 +452,7 @@ void KTransferImpl::opProcessStart()
    _timeEst.setHMS(0, 0, 0);
    _killed = false;
    _stopped = false;
+   _restart = false;
    if (getLogProcess())
    {
       QString logname = QFileInfo(
@@ -586,7 +589,10 @@ void KTransferImpl::opProcessEnd(int exitStatus)
 	 if (_checkResume == 1)
 	    setState(TRN_READY);
 	 else
+	 {
+	    _restart = true;
 	    _wait.start(100, true);
+	 }
       }
       kdDebug(D_RUN) << name() << ": state after check :" << stateStr() << endl;
       _checkResume = 0;
