@@ -4,7 +4,7 @@
     begin                : Sun Nov 5 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.10 $
+    revision             : $Revision: 1.12 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -62,10 +62,13 @@ void KTransferKioImpl::loadData()
    kdDebug(D_INI) << name() << ": kio loadData" << endl;
    if (!dom().hasAttribute("DisableCookie"))
    {
-      dom().setAttribute("DisableCookie", 0);
+      dom().setAttribute("DisableCookie", false);
+      dom().setAttribute("DisableCache", false);
    }
    _cfg_disableCookie = dom().attribute("DisableCookie", 
 					QString::number(false)).toInt();
+   _cfg_disableCache = dom().attribute("DisableCache", 
+					QString::number(false)).toInt();
 }
 
 KURL KTransferKioImpl::getTempFile(const KURL &rmt, const KURL &) const 
@@ -91,7 +94,8 @@ void KTransferKioImpl::startJob(unsigned long offset, bool resumeOrAbort)
 {
    kdFatal(_job != 0, D_RUN) << name() << ": start job != 0" << endl;
    _startDownload = true;
-   _job = new KTransferJob(remote(), tmp(), offset, resumeOrAbort, getDisableCookie());
+   _job = new KTransferJob(remote(), tmp(), offset, resumeOrAbort, 
+			   getDisableCookie(), getDisableCache());
    if (_job == 0) 
    {
       kdError(D_RUN) << name() << ": start job null" << endl;
@@ -295,16 +299,33 @@ void KTransferKioImpl::setDisableCookie(bool v)
    }
 }
 
+bool KTransferKioImpl::getDisableCache() const
+{
+   return useGlobal() ? global()->getDisableCache() : _cfg_disableCache;
+}
+
+void KTransferKioImpl::setDisableCache(bool v)
+{
+   if (_cfg_disableCache != v)
+   {
+      _cfg_disableCache = v;
+      dom().setAttribute("DisableCache", _cfg_disableCache);
+      setMod(MDI_TRK_CFG_CACHE);
+      root()->setModified();
+   }
+}
+
 //////////////////////////////////////////////////////////////////////
 
 int KTransferJob::_cnt = 0;
 
 KTransferJob::KTransferJob(const KURL &src, const KURL &dest, 
 			   unsigned long srcOffset, bool resumeOrAbort, 
-			   bool disableCookie) 
+			   bool disableCookie, bool disableCache) 
    : SimpleJob("", 0, QByteArray(), false), _src(src), _dest(dest), 
      _canResume(false), _resumeAnswerSent(false), _resumeOrAbort(resumeOrAbort), 
-     _disableCookie(disableCookie), _srcOffset(srcOffset), _totalSize(0), 
+     _disableCookie(disableCookie), _disableCache(disableCache), 
+     _srcOffset(srcOffset), _totalSize(0), 
      _getJob(0), _putJob(0) 
 {
    setName(QString("KTransferJob-%1").arg(_cnt++));
@@ -345,6 +366,8 @@ void KTransferJob::slotCanResume(KIO::Job *job, unsigned long offset)
       _getJob = KIO::get(_src, false, false);
       if (_disableCookie)
 	 _getJob->addMetaData("cookies", "none");
+      if (_disableCache)
+	 _getJob->addMetaData("no-cache", "true");
       kdDebug(D_RUN) << name() << ": create get job " << _getJob << endl;
       // if _srcOffset != 0 we have a source offset != from the dest offset
       if (_srcOffset == 0)
