@@ -4,7 +4,7 @@
     begin                : Sun Nov 5 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.7 $
+    revision             : $Revision: 1.9 $
  ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -17,16 +17,17 @@
 #ifndef KTRANSFERKIOIMPL_H
 #define KTRANSFERKIOIMPL_H
 
-//#include <kio/global.h>
 #include <kio/job.h>
 #include "ktransferimpl.h"
 
+#include <kio/global.h>
+
 /**
  * @short Concrete implementation of transfer based on @ref KIO::job.
  *
  * @author Sergio Moretti
  *
- * @version $Id: ktransferkioimpl.h,v 1.7 2001/03/22 09:26:52 sergio Exp $
+ * @version $Id: ktransferkioimpl.h,v 1.9 2001/04/02 20:38:51 sergio Exp $
  */
 
 class KTransferKioImpl : public KTransferImpl  
@@ -48,6 +49,8 @@ public:
 
    bool getDisableCookie() const;
    void setDisableCookie(bool v);
+   bool getDisableCache() const;
+   void setDisableCache(bool v);
 
 protected:
    /** create empty transfer */
@@ -103,6 +106,7 @@ private:
 
    // config
    bool _cfg_disableCookie;
+   bool _cfg_disableCache;
 };
 
 /**
@@ -110,7 +114,7 @@ private:
  *
  * @author Sergio Moretti
  *
- * @version $Id: ktransferkioimpl.h,v 1.7 2001/03/22 09:26:52 sergio Exp $
+ * @version $Id: ktransferkioimpl.h,v 1.9 2001/04/02 20:38:51 sergio Exp $
  */
 
 class KTransferJob : public KIO::SimpleJob 
@@ -119,9 +123,11 @@ class KTransferJob : public KIO::SimpleJob
 
 public:
    KTransferJob(const KURL &src, const KURL &dest, unsigned long srcOffset, 
-		bool resumeOrAbort, bool disableCookie);
+		bool resumeOrAbort, bool disableCookie, bool disableCache);
    ~KTransferJob();
 
+   //static KIO::SlaveManagerGlobal * managerInstance();
+
 protected:
    void connectSubjob(KIO::SimpleJob * job );
 
@@ -140,6 +146,8 @@ protected slots:
 
    void slotResult(KIO::Job *job);
 
+   //void slotNeedConfiguration(KIO::Job *job, const KIO::MetaData &data);
+
 signals:
    void sigConnect();
 
@@ -149,12 +157,14 @@ signals:
 
 private:
    KURL _src, _dest;
-   bool _canResume,_resumeAnswerSent, _resumeOrAbort, _disableCookie;
+   bool _canResume,_resumeAnswerSent, _resumeOrAbort, _disableCookie, 
+      _disableCache;
    unsigned long _srcOffset, _totalSize;
    KIO::TransferJob *_getJob, *_putJob;
    QByteArray _buffer;
 
    static int _cnt;
+   //static KIO::SlaveManagerGlobal *_managerInstance;
 };
 
 #endif
